@@ -117,12 +117,13 @@ def _buildDictionary(componentOption):
 	data = (componentOption)
 	paramsString = db.execSelectQueryScalar(sql, data)
 	
-	parms = paramsString.split()
+	parms = paramsString.split("\n")
 	
 	parmsDict = {}
 	for parmline in parms:
-		n,v = parmline.split("=", 1)
-		parmsDict[n] = v
+		if parmline: # in case of any blank lines in the params field
+			n,v = parmline.split("=", 1)
+			parmsDict[n] = v
 		
 	return parmsDict
 	
