@@ -41,9 +41,9 @@ def _del_jos_xgroups(db, name):
 
 
 def _add_ldap_group(groupName, groupDescription, gidNumber):
-	hubLDAPAcctMgrPW = hubzero.config.webconfig.getWebConfigOption("hubLDAPAcctMgrPW")	
-	hubLDAPAcctMgrDN = hubzero.config.webconfig.getWebConfigOption("hubLDAPAcctMgrDN")	
-	hubLDAPBaseDN = hubzero.config.webconfig.getWebConfigOption("hubLDAPBaseDN")
+	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
+	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
+	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")
 
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
@@ -52,19 +52,18 @@ def _add_ldap_group(groupName, groupDescription, gidNumber):
 	attrs = {}
 	attrs['objectclass'] = ['posixGroup', 'top']
 	attrs['cn'] = groupName
-	attrs['gidNumber'] =str( gidNumber)
+	attrs['gidNumber'] = str(gidNumber)
 	attrs['description'] = groupDescription
-	attrs['ou'] = 'groups'
 	ldif = ldap.modlist.addModlist(attrs)
-	print ldif
+	print "adding group with dn: " + dn
 	l.add_s(dn, ldif)
 
 
 def _del_ldap_group(groupName):
 	# get ldapManagerUserDN and PW
-	hubLDAPAcctMgrPW = hubzero.config.webconfig.getWebConfigOption("hubLDAPAcctMgrPW")	
-	hubLDAPAcctMgrDN = hubzero.config.webconfig.getWebConfigOption("hubLDAPAcctMgrDN")	
-	hubLDAPBaseDN = hubzero.config.webconfig.getWebConfigOption("hubLDAPBaseDN")
+	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
+	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
+	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")
 
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
