@@ -270,10 +270,10 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 		# set ownership
 		os.chown(homeDir, userID, gidNumber)
 		
-		#rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["chown", username + "." + username, homeDir])
-		#print procStdOut
-		#if rc:
-		#	print procStdErr
+		# change permissions user full, noone else has anything
+		rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["chmod", '700', homeDir])
+		if rc:
+			print procStdErr
 		
 	return(0)
 
